<?php
/**
 * Functions
 *
 * This file loads the other
 * files required by the theme.
 * Only edit it if you know what
 * you're doing.
 *
 * @package Live
 * @since 3.0.0
 *
 */

// Define Version
	define( 'LIVE_VERSION', '3.2.6' );

// options framework
	if ( !function_exists( 'optionsframework_init' ) ) {
		define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/inc/' );
		require_once dirname( __FILE__ ) . '/inc/options-framework.php';
	}
	
	// loads options file directly as required by theme customizer
		require_once dirname( __FILE__ ) . '/options.php';

// include required files
	include(get_template_directory()."/includes/fonts.php");
	include(get_template_directory()."/includes/images.php");
	include(get_template_directory()."/includes/titles.php");
	include(get_template_directory()."/includes/scripts.php");
	include(get_template_directory()."/includes/body-tag.php");
	include(get_template_directory()."/includes/custom-js.php");
	include(get_template_directory()."/includes/custom-css.php");
	include(get_template_directory()."/includes/content-limit.php");
	include(get_template_directory()."/includes/tha-theme-hooks.php");
	include(get_template_directory()."/includes/theme-customizer.php");
	include(get_template_directory()."/includes/comment-functions.php");
	include(get_template_directory()."/includes/custom-meta-boxes/live.php");

// widget related files
	include(get_template_directory()."/includes/widgets.php");
	include(get_template_directory()."/includes/widget-video.php");
	include(get_template_directory()."/includes/widget-last-podcast.php");
	include(get_template_directory()."/includes/widget-featured-page.php");
	include(get_template_directory()."/includes/widget-featured-post.php");
	include(get_template_directory()."/includes/widget-facebook-like-box.php");

// custom post types
	include(get_template_directory()."/includes/post-types/staff.php");
	include(get_template_directory()."/includes/post-types/slides.php");
	include(get_template_directory()."/includes/post-types/podcast.php");
	include(get_template_directory()."/includes/post-types/admin-style.php");

// optional includes
	// include organized themes gallery
		if(of_get_option('gallery') == 'true') {
			include(get_template_directory()."/includes/lightbox.php");
		}




// Other Theme Functions

	if ( ! function_exists( 'live_setup' ) ):

		function live_setup() {
			
			// For localization
				load_theme_textdomain( 'organizedthemes', get_template_directory().'/languages' );
			
			// Add default posts and comments RSS feed links to head
				add_theme_support( 'automatic-feed-links' );
			
			// This theme uses wp_nav_menu() in one location.
				register_nav_menus( array(
					'primary' => __( 'Header', 'organizedthemes' ),
				) );
			
			// Trim Excerpt . . .	
				function organizedthemes_excerpt( $more ) {
					return '';
				}
				add_filter('excerpt_more', 'organizedthemes_excerpt');
			
			// Post Formats	
				add_theme_support( 'post-formats', array( 'image', 'video' ) );
					add_post_type_support( 'page', 'post-formats' );
					add_post_type_support( 'podcast', 'post-formats' );
			
		}
		
	endif; // live_setup
	
	add_action( 'after_setup_theme', 'live_setup' );




// Go to theme options after theme activated
	if ( is_admin() and isset($_GET['activated'] ) and $pagenow == "themes.php" ) {
		wp_redirect( 'themes.php?page=options-framework' );
	}




// Flush rewrite rules on theme activation
	function organizedthemes_flush_rewrite() {
		global $pagenow, $wp_rewrite;
	
		if ( 'themes.php' == $pagenow && isset( $_GET['activated'] ) )
			$wp_rewrite->flush_rules();
	}

	add_action( 'load-themes.php', 'organizedthemes_flush_rewrite' );





// Reverse Escape Function For Podcast Categories
	
	if ( ! function_exists( 'reverse_escape' ) ):
	
		function reverse_escape($str) {
		
			$search=array("\\\\","\\0","\\n","\\r","\Z","\'",'\"');
			$replace=array("\\","\0","\n","\r","\x1a","'",'"');
			return str_replace($search,$replace,$str);
		
		}
	
	endif; // reverse_escape



// Theme Updater

	if ( !of_get_option( 'disable_theme_updater' ) ) {
	
		function organizedthemes_theme_update(){
		
			/* updater args */
			$updater_args = array(
				'repo_uri'    => 'http://support.organizedthemes.com/',
				'repo_slug'   => 'live-update',
				'dashboard'   => false,
				'username'    => false,
			);
		
			/* add support for updater */
			add_theme_support( 'auto-hosted-theme-updater', $updater_args );
		}
		
		add_action( 'after_setup_theme', 'organizedthemes_theme_update' );
		require_once( trailingslashit( get_template_directory() ) . 'includes/theme-updater.php' );
		new Live_Theme_Updater;
	
	}
