<?php
/**
 * Podcast Post Type
 *
 * This file creates the podcast post type
 * and controls its display in the admin.
 *
 * @package WordPress
 * @subpackage Organized Themes
 * @since 1.0.0
 */

// Register podcast Post Type

		register_post_type( 'podcast',
			array(
				'labels' 				=> array(
				'name' 					=> __( 'Podcast', 'organizedthemes' ),
				'singular_name' 		=> __( 'Podcast', 'organizedthemes' ),
				'add_new' 				=> __( 'Add New Podcast', 'organizedthemes' ),
				'add_new_item' 			=> __( 'Add New Podcast', 'organizedthemes' ),
				'edit' 					=> __( 'Edit Podcast', 'organizedthemes' ),
				'edit_item' 			=> __( 'Edit Podcast', 'organizedthemes' ),
				'view' 					=> __( 'View Podcast', 'organizedthemes' ),
				'view_item' 			=> __( 'View Podcast', 'organizedthemes' ),
				'not_found' 			=> __( 'No podcasts', 'organizedthemes' ),
				'not_found_in_trash' 	=> __( 'Your podcasts are not in the trash', 'organizedthemes' ),
			),
				'public' 				=> true,
				'show_ui' 				=> true,
				'hierarchical' 			=> true,
				'publicly_queryable' 	=> true,
				'has_archive' 			=> true,
				'exclude_from_search' 	=> false,
				'show_in_nav_menus'		=> false,
				'capability_type'		=> 'post',
				'menu_icon' 			=> get_template_directory_uri() . '/images/podcast.png',
	    		'supports' 				=> array('title', 'editor', 'thumbnail', 'page-attributes')
			)
			
		);
	
	// Register Message Series
		register_taxonomy( 'series', 'podcast', 
			array( 
				'hierarchical' => true, 
					'labels' => array(
						'name' 				=> __( 'Series', 'organizedthemes' ),
						'singular_name' 	=> __( 'Series', 'organizedthemes' ),
						'search_items' 		=> __( 'Search Series', 'organizedthemes' ),
						'popular_items' 	=> __( 'Popular Series', 'organizedthemes' ),
						'all_items' 		=> __( 'All Series', 'organizedthemes' ),
						'parent_item' 		=> __( 'Parent Series', 'organizedthemes' ),
						'parent_item_colon' => __( 'Parent Series:', 'organizedthemes' ),
						'edit_item' 		=> __( 'Edit Series', 'organizedthemes' ),
						'update_item' 		=> __( 'Update Series', 'organizedthemes' ),
						'add_new_item' 		=> __( 'Add New Series', 'organizedthemes' ),
						'new_item_name' 	=> __( 'New Series Name', 'organizedthemes' ),
					), 
				'query_var' => true,
				'rewrite' => array( 'slug' => 'series', 'with_front' => false )
				) 
		); 
	
	// Register Speaker Type
		register_taxonomy( 'speaker', 'podcast', 
			array( 
				'hierarchical' => true, 
					'labels' => array(
						'name' 				=> __( 'Speaker', 'organizedthemes' ),
						'singular_name' 	=> __( 'Speaker', 'organizedthemes' ),
						'search_items' 		=> __( 'Search Speakers', 'organizedthemes' ),
						'popular_items' 	=> __( 'Popular Speakers', 'organizedthemes' ),
						'all_items' 		=> __( 'All Speakers', 'organizedthemes' ),
						'parent_item' 		=> __( 'Parent Speakers', 'organizedthemes' ),
						'parent_item_colon' => __( 'Parent Speakers:', 'organizedthemes' ),
						'edit_item' 		=> __( 'Edit Speaker', 'organizedthemes' ),
						'update_item' 		=> __( 'Update Speaker', 'organizedthemes' ),
						'add_new_item' 		=> __( 'Add New Speaker', 'organizedthemes' ),
						'new_item_name' 	=> __( 'New Speaker Name', 'organizedthemes' ),
					), 
				'query_var' => true,
				'rewrite' => array( 'slug' => 'speaker', 'with_front' => false )
				) 
		);
	

//  Create columns for podcast dashboard
//  http://wptheming.com/2010/07/column-edit-pages/

add_filter("manage_edit-podcast_columns", "podcast_edit_columns");
add_action("manage_pages_custom_column",  "podcast_columns_display", 10, 2);

 
function podcast_edit_columns($podcast_columns){
	$podcast_columns = array(
		"cb" 				=> "<input type=\"checkbox\" />",
		"date" 				=> __('Date', 'organizedthemes'),
		"podcast_thumbnail"	=> __('Artwork', 'organizedthemes'),
		"title" 			=> __('Name', 'organizedthemes'),
		"podcast_speaker" 	=> __('Speaker', 'organizedthemes'),
		"podcast_group" 	=> __('Series', 'organizedthemes'),
		"podcast_content" 	=> __('Content', 'organizedthemes'),
	);
	return $podcast_columns;
}
 
function podcast_columns_display($podcast_columns, $post_id){

	switch ($podcast_columns)
	
	{
		// Code from: http://wpengineer.com/display-post-thumbnail-post-page-overview
		
		case "podcast_thumbnail": //Adds the podcast's logo to the columns
			$width = (int) 170;
			$height = (int) 106;
			$thumbnail_id = get_post_meta( $post_id, '_thumbnail_id', true );
			
			// Display the featured image in the column view if possible
			if ($thumbnail_id) {
				$thumb = wp_get_attachment_image( $thumbnail_id, array($width, $height), true );
			}
			if ( isset($thumb) ) {
				echo $thumb;
			} else {
				echo __('No Image Set', 'organizedthemes');
			}
			break;
		
		case "date": //Adds the podcast's web address to the columns
			the_date();
			break;
		
		case "podcast_link": //Adds the podcast's web address to the columns
			$custom = get_post_custom();
			echo $custom["podcast_url"][0];
			break;
		
		case "podcast_content": //Adds your podcast's excerpt to the columns
			the_excerpt();
			break;
		
		case "podcast_group": //Adds the series to the columns
			echo get_the_term_list($post->ID, 'series', '', ', ','');
			break;	
			
		case "podcast_speaker": //Adds the speaker to the columns
			echo get_the_term_list($post->ID, 'speaker', '', ', ','');
			break;		
	}
}

//change title to slide description
	function organizedthemes_podcast_title( $title ){
	     $screen = get_current_screen();
	 
	     if  ( 'podcast' == $screen->post_type ) {
	          $title = 'Enter Podcast Title';
	     }
	 
	     return $title;
	}
	 
	add_filter( 'enter_title_here', 'organizedthemes_podcast_title' );
		
?>