<?php
/**
 * Staff Post Type
 *
 * This file creates the staff post type
 * and also controls its function and 
 * display in the dashboard
 *
 * @package Live
 * @since 3.0.0
 */

// Register Staff Post Type
	register_post_type( 'staff',
		array(
			'labels' 				=> array(
			'name' 					=> __( 'Staff', 'organizedthemes' ),
			'singular_name' 		=> __( 'Staff', 'organizedthemes' ),
			'add_new' 				=> __( 'Add New Staff Member', 'organizedthemes' ),
			'add_new_item' 			=> __( 'Add New Staff Member', 'organizedthemes' ),
			'edit' 					=> __( 'Edit', 'organizedthemes' ),
			'edit_item' 			=> __( 'Edit Staff Member', 'organizedthemes' ),
			'view' 					=> __( 'View Staff', 'organizedthemes' ),
			'view_item' 			=> __( 'View Staff Member', 'organizedthemes' ),
			'not_found' 			=> __( 'No staff members', 'organizedthemes' ),
			'not_found_in_trash' 	=> __( 'Your staff is not in the trash', 'organizedthemes' ),
		),
			'public' 				=> true,
			'show_ui' 				=> true,
			'hierarchical' 			=> true,
			'publicly_queryable' 	=> true,
			'exclude_from_search' 	=> false,
			'show_in_nav_menus'		=> false,
			'menu_icon' 			=> get_template_directory_uri() . '/images/staff.png',
    		'supports' 				=> array('title', 'editor', 'thumbnail', 'excerpt', 'page-attributes')
		)
		
	);

// Register Staff Group Taxonomy
	register_taxonomy( 'staff-group', 'staff', 
		array( 
			'hierarchical' => true, 
				'labels' => array(
					'name' 				=> __( 'Staff Type', 'organizedthemes' ),
					'singular_name' 	=> __( 'Staff Type', 'organizedthemes' ),
					'search_items' 		=> __( 'Search Staff Types', 'organizedthemes' ),
					'popular_items' 	=> __( 'Popular Staff Types', 'organizedthemes' ),
					'all_items' 		=> __( 'All Staff Types', 'organizedthemes' ),
					'parent_item' 		=> __( 'Parent Staff Types', 'organizedthemes' ),
					'parent_item_colon' => __( 'Parent Staff Types:', 'organizedthemes' ),
					'edit_item' 		=> __( 'Edit Staff Type', 'organizedthemes' ),
					'update_item' 		=> __( 'Update Staff Type', 'organizedthemes' ),
					'add_new_item' 		=> __( 'Add New Staff Type', 'organizedthemes' ),
					'new_item_name' 	=> __( 'New Staff Type Name', 'organizedthemes' ),
				), 
			'query_var' => true,
			'rewrite' => array( 'slug' => 'staff-group', 'with_front' => false )
			) 
	);

//  Add columns to staff dashboard
//  http://wptheming.com/2010/07/column-edit-pages/

add_filter("manage_edit-staff_columns", "staff_edit_columns");
add_action("manage_pages_custom_column",  "staff_columns_display", 10, 2);

 
function staff_edit_columns($staff_columns){
	$staff_columns = array(
		"cb" 				=> "<input type=\"checkbox\" />",
		"staff_thumbnail" 	=> __('Staff Picture', 'organizedthemes'),
		"title" 			=> __('Name', 'organizedthemes'),
		"staff_title" 		=> __('Title', 'organizedthemes'),
		"staff_group" 		=> __('Staff Group', 'organizedthemes'),
		"staff_content" 	=> __('Bio', 'organizedthemes'),	);
	return $staff_columns;
}
 
function staff_columns_display($staff_columns, $post_id){

	switch ($staff_columns)
	
	{
		// Code from: http://wpengineer.com/display-post-thumbnail-post-page-overview
		
		case "staff_thumbnail": //Adds the staff members image to the columns
			$width = (int) 200;
			$height = (int) 200;
			$thumbnail_id = get_post_meta( $post_id, '_thumbnail_id', true );
			
			// Display the featured image in the column view if possible
			if ($thumbnail_id) {
				$thumb = wp_get_attachment_image( $thumbnail_id, array($width, $height), true );
			}
			if ( isset($thumb) ) {
				echo $thumb;
			} else {
				echo __('Add a featured image to include a picture', 'organizedthemes');
			}
			break;

		case "staff_title": //Adds the staff member's title to the columns
			$custom = get_post_custom();
			echo $custom["title"][0];
			break;	
			
		case "staff_content": //Adds the excerpt to the bio column
			the_excerpt();
			break;	
		
		case "staff_group": //Adds the staff group to the columns
			echo get_the_term_list($post->ID, 'staff-group', '', ', ','');
			break;	
		
	}
}

//change title to staff member name
	function organizedthemes_staff_title( $title ){
	     $screen = get_current_screen();
	 
	     if  ( 'staff' == $screen->post_type ) {
	          $title = 'Enter Staff Member Name';
	     }
	 
	     return $title;
	}
	 
	add_filter( 'enter_title_here', 'organizedthemes_staff_title' );
		
?>