<?php

/**
 * The theme options list 
 *
 * This file works with the options framework
 * to generate the theme options page and set
 * our theme options
 *
 * @package Live
 * @since  3.0.0
 */
 
 
$settings = get_current_theme().'-options'; // do not change!

$defaults = array( // define our defaults
		'color_style' 			=> 'gradient',
		'header_blog_title' 	=> 'Text',
		'favicon' 				=> 'http://www.organizedthemes.com/images/favicon.ico',
		'apple-icon' 			=> 'http://www.organizedthemes.com/images/apple-touch-icon.png',
		'action'		 		=> 'Yes',
		'action_text'	 		=> 'Call To Action Button',
		'action_url'	 		=> '',
		'twitter'	 			=> '',
		'facebook-header'		=> '',
		'custom_style'	 		=> 'No',
		'tracking'				=> '<!-- paste tracking code here-->' // <-- no comma after the last option
);

//	push the defaults to the options database,
//	if options don't yet exist there.
add_option($settings, $defaults, '', 'yes');

//	this function registers our settings in the db
add_action('admin_init', 'register_theme_settings');
function register_theme_settings() {
	global $settings;
	register_setting($settings, $settings);
}
//	this function adds the settings page to the menu
add_action('admin_menu', 'add_theme_options_menu');
function add_theme_options_menu() {
	add_submenu_page('themes.php', "Live Theme", "Live Theme", 'edit_others_posts', basename(__FILE__), 'theme_settings_admin');
}

function theme_settings_admin() { ?>
<?php theme_options_css_js(); ?>
<div class="wrap">
<?php
	// display the proper notification if Saved/Reset
	global $settings, $defaults;
	if(ot_option('reset')) {
		echo '<div class="updated fade" id="message"><p>Theme Options <strong>RESET TO DEFAULTS</strong></p></div>';
		update_option($settings, $defaults);
	} elseif($_REQUEST['updated'] == 'true') {
		echo '<div class="updated fade" id="message"><p>Theme Options <strong>SAVED</strong></p></div>';
	}
	// display icon next to page title
	screen_icon('options-general');
?>
	<h2><?php echo get_current_theme() . ' '; _e('Theme Options'); ?></h2>
	<form method="post" action="options.php">
	<?php settings_fields($settings); // important! ?>
	
	<!--left column-->
	<div class="metabox-holder">
    
		<div class="postbox">
		<h3>Design Style</h3>
			<div class="inside">
				<p>Select from the following:<br />
				<select name="<?php echo $settings; ?>[color_style]">
					<option value="gold" <?php selected('gold', ot_option('color_style')); ?>>Gold</option>
					<option value="gradient" <?php selected('gradient', ot_option('color_style')); ?>>Gradient</option>
					<option value="leather" <?php selected('leather', ot_option('color_style')); ?>>Leather</option>
					<option value="metal" <?php selected('metal', ot_option('color_style')); ?>>Metal</option>
					<option value="sponge" <?php selected('sponge', ot_option('color_style')); ?>>Sponge</option>
				</select></p>
			</div>
		</div>
		
		<div class="postbox">
		<h3>Identity and Social Networking</h3>
			<div class="inside">
				<p>Choose logo type:<br />
				<select name="<?php echo $settings; ?>[header_blog_title]">
					<option style="padding-right:10px;" value="Image" <?php selected('Image', ot_option('header_blog_title')); ?>>Use an image logo</option>
					<option style="padding-right:10px;" value="Text" <?php selected('Text', ot_option('header_blog_title')); ?>>Use dynamic text</option>
				</select></p>
                
				<p>Type the URL for your logo here.<br />
				<input type="text" name="<?php echo $settings; ?>[logo]" value="<?php echo ot_option('logo'); ?>" size="45" /></p>    
				<p>Type the URL for your favicon (small png or gif image that appears in the browser navigation bar) here.<br />
				<input type="text" name="<?php echo $settings; ?>[favicon]" value="<?php echo ot_option('favicon'); ?>" size="45" /></p>
				<p>Type the URL for your Twitter account here.<br />
				<input type="text" name="<?php echo $settings; ?>[twitter]" value="<?php echo ot_option('twitter'); ?>" size="45" /></p>
				<p>Type the URL for your Facebook account here.<br />
				<input type="text" name="<?php echo $settings; ?>[facebook-header]" value="<?php echo ot_option('facebook-header'); ?>" size="45" /></p>
                
            </div>
		</div>
		
		<div class="postbox">
		<h3>Home Page Slideshow or Video</h3>
			<div class="inside">
				<p><?php _e("Choose between a slideshow or a video for your front page", 'organizedthemes'); ?><br />
				<select name="<?php echo $settings; ?>[front_page]">
					<option value="image" <?php selected('image', ot_option('front_page')); ?>>Image</option>
					<option value="video" <?php selected('video', ot_option('front_page')); ?>>Video</option>
				</select></p>
                
				<p><?php _e("Paste your video embed code here:", 'organizedthemes'); ?><br />
				<textarea name="<?php echo $settings; ?>[video_embed]" cols=35 rows=5><?php echo stripslashes(ot_option('video_embed')); ?></textarea><br />
				<em><?php _e("For best results set your video to 870 pixels wide", 'organizedthemes'); ?></em>
				</p>
			</div>
		</div>
				
		<div class="postbox">
		<h3>Call To Action Bar</h3>
			<div class="inside">
                <p>Do you want to use the call to action bar?<br />
				<select name="<?php echo $settings; ?>[action]">
					<option value="Yes" <?php selected('Yes', ot_option('action')); ?>>Yes</option>
					<option value="No" <?php selected('No', ot_option('action')); ?>>No</option>
				</select></p>
				
				<p>Type the text for your call to action button here.<br />
				<input type="text" name="<?php echo $settings; ?>[action_text]" value="<?php echo ot_option('action_text'); ?>" size="45" /></p>
				
				<p>Type the URL for your call to action button here.<br />
				<input type="text" name="<?php echo $settings; ?>[action_url]" value="<?php echo ot_option('action_url'); ?>" size="45" /></p>
			
            </div>
		</div>
				
        <div class="postbox">
		<h3><?php _e("Analytics Code", 'organizedthemes'); ?></h3>
			<div class="inside">
				<p>If you use a service such as <a href="http://www.google.com/analytics/">Google Analytics</a> to track analytics on your site, paste the code below (it will be inserted into the footer):</p>
				<p>
				<textarea name="<?php echo $settings; ?>[tracking]" cols=30 rows=5><?php echo stripslashes(ot_option('tracking')); ?></textarea>
				</p>
			</div>
		</div>
		 		       
	</div>
	<!--end first column-->
	
	<!--second column-->
	<div class="metabox-holder">
    	
		<div class="postbox">
		<h3><?php _e("Organized Themes Help & More", 'organizedthemes'); ?></h3>
			<div class="inside">
				<p><strong>Need Help?</strong><br />At Organized Themes, we're here to help you.  Just follow these links to find the answers you need:</p>
				<ul>
					<li><a href="http://codex.wordpress.org" target="_blank">WordPress Codex</a></li>
					<li><a href="http://www.organizedthemes.com/support" target="_blank">Support Page</a></li>
					<li><strong><a href="http://www.organizedthemes.com/live-theme-instuctions/" target="_blank">Live Theme Instructions</a></strong></li>
				</ul>
				<span style="border-bottom: 1px solid #CCC; width: 100%; display: block;"</span>
				<p><strong>Ready for the Organized Themes Package?</strong> <br />  <a rel="nofollow" href="http://www.organizedthemes.com/theme-package/">Upgrade to it</a> and get all of our themes for only $50!<br /><strong><small>(Use UP50 as the discount code and save!)</small></strong></p>
                <p><span style="float:left;margin-bottom:10px;"<a target="_blank" href="http://feeds.feedburner.com/organizedthemes/KxLG">Subscribe to RSS Feed</a></span> <span style="float:right"><a target="_blank" href="http://www.organizedthemes.com/themes">See more themes</a></span></p>
				<div style="clear:both;"></div>

			</div>
		</div>		
		<div class="postbox">
		
		<h3>Custom Styles</h3>
			<div class="inside">
					
				<p>Do you want to include any custom styling?<br />
				<select name="<?php echo $settings; ?>[custom_style]">
					<option value="Yes" <?php selected('Yes', ot_option('custom_style')); ?>>Yes</option>
					<option value="No" <?php selected('No', ot_option('custom_style')); ?>>No</option>
				</select></p>
                <p>All styles are optional.  Just include the ones you'd like to change.  You can enter any custom css in the box at the bottom.  Be sure to use hex color codes for colors (like #cccccc for silver).  You can learn more <a href="http://www.colorpicker.com/" target="_blank">here and pick colors.</a>  You can edit the background by going to the background menu</p>
				<p>Enter your link color here.<br />
				<input type="text" name="<?php echo $settings; ?>[link_color]" value="<?php echo ot_option('link_color'); ?>" size="10" /></p>
				
				<p>Enter your link hover color here.<br />
				<input type="text" name="<?php echo $settings; ?>[link_color_hover]" value="<?php echo ot_option('link_color_hover'); ?>" size="10" /></p>
                
				<p>Enter your header color here.<br />
				<input type="text" name="<?php echo $settings; ?>[header_color]" value="<?php echo ot_option('header_color'); ?>" size="10" /></p>
				
				<p>Enter your header <em>hover</em> color here.<br />
				<input type="text" name="<?php echo $settings; ?>[header_color_hover]" value="<?php echo ot_option('header_color_hover'); ?>" size="10" /></p>
                
				<p>Enter your footer color here.<br />
				<input type="text" name="<?php echo $settings; ?>[footer_color]" value="<?php echo ot_option('footer_color'); ?>" size="10" /></p>
                
				<p>Enter your custom css code here<br />
				<textarea name="<?php echo $settings; ?>[custom_css_code]" cols=35 rows=5><?php echo stripslashes(ot_option('custom_css_code')); ?></textarea></p>
            </div>
		</div>           
        		
		<p class="submit">
		<input type="submit" class="button-primary" value="<?php _e('Save Settings', 'organizedthemes') ?>" />
		<input type="submit" class="button-highlighted" name="<?php echo $settings; ?>[reset]" value="<?php _e('Reset Settings', 'organizedthemes'); ?>" />
		</p>

	</div>
	<!--end second column-->
	
	</form>

</div><!--end .wrap-->
<?php }

// add CSS and JS if necessary
function theme_options_css_js() {
echo <<<CSS

<style type="text/css">
	.metabox-holder { 
		width: 350px; float: left;
		margin: 0px; padding: 0px 10px 0px 0px;
	}
	.metabox-holder .postbox .inside {
		padding: 0px 10px 0px 10px;
	}
</style>

CSS;

echo <<<JS

<script type="text/javascript">
jQuery(document).ready(function($) {
	$(".fade").fadeIn(1000).fadeTo(1000, 1).fadeOut(1000);
});
</script>

JS;
}
?>