<?php
/**
 * Last Podcast Widget
 *
 * Creates a widget that displays
 * the latest podcast episode
 *
 * @package 	Live
 * @since  		3.1.0
 */

add_action('widgets_init', create_function('', "register_widget('OrganizedThemes_Last_Podcast');"));
class OrganizedThemes_Last_Podcast extends WP_Widget {

	function OrganizedThemes_Last_Podcast() {
		$widget_ops = array( 'classname' => 'last-podcast', 'description' => __('Displays the last podcast episode', 'organizedthemes') );
		$control_ops = array( 'width' => 200, 'height' => 250, 'id_base' => 'last-podcast' );
		$this->WP_Widget( 'last-podcast', __('Last Podcast Widget', 'organizedthemes'), $widget_ops, $control_ops );
	}

	function widget($args, $instance) {
		extract($args);
		
		$instance = wp_parse_args( (array)$instance, array(
			'title' => '',
			'more_label' => '',
			'more_link' => ''
		) );
		
		echo $before_widget;

		 if (!empty($instance['title']))
			echo $before_title . apply_filters('widget_title', $instance['title']) . $after_title;

		// Loop For Podcasts
		
		$podcast_query = new WP_Query( "post_type=podcast&posts_per_page=1" );
		global $post;
		while ( $podcast_query->have_posts() ) : $podcast_query->the_post(); ?>
		
		<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'episode' ); ?></a>
		<h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
		<p class="meta"><?php the_time('F j, Y'); ?> <?php _e('by', 'organizedthemes'); ?> <?php echo get_the_term_list( get_the_ID(), 'speaker' ) ?></p>
		
		<p class="podcast-meta">
			<span class="genericon genericon-audio"><a href="<?php the_permalink(); ?>"><?php _e('Listen', 'organizedthemes'); ?></a></span>
			<span class="genericon genericon-reply"><a href="<?php echo get_post_meta($post->ID, "message_audio", TRUE); ?>"><?php _e('Download', 'organizedthemes'); ?></a></span>
			<?php if(get_post_meta($post->ID, "message_notes", $single = true) != ""){ ?>
			<span class="genericon genericon-standard"><a href="<?php echo get_post_meta($post->ID, "message_notes", TRUE); ?>"><?php _e('Notes', 'organizedthemes'); ?></a></span>
			<?php } ?>
		</p>
			
		<?php endwhile; wp_reset_postdata(); 
		
		if (!empty($instance['more_link'])) { ?>
		
		<a class="button" href="<?php echo $instance['more_link'] ?>"><?php echo$instance['more_label'] ?></a>
		
		<?php } 
				
		echo $after_widget;
		
	}

	function update($new_instance, $old_instance) {
		return $new_instance;
	}

	function form($instance) { 
		
		$instance = wp_parse_args( (array)$instance, array(
			'title' => '',
			'more_label' => '',
			'more_link' => ''
		) );
		
?>
		
		<p>
			<?php _e('This widget displays the most recent podcast episode along with the featured image for that podcast.  It also has an optional link you can use to send visitors to your podcast archive.', 'organizedthemes'); ?>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'organizedthemes'); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" style="width:95%;" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('more_label'); ?>"><?php _e('More Label', 'organizedthemes'); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id('more_label'); ?>" name="<?php echo $this->get_field_name('more_label'); ?>" value="<?php echo esc_attr( $instance['more_label'] ); ?>" style="width:95%;" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('more_link'); ?>"><?php _e('More URL', 'organizedthemes'); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id('more_link'); ?>" name="<?php echo $this->get_field_name('more_link'); ?>" value="<?php echo esc_attr( $instance['more_link'] ); ?>" style="width:95%;" />
		</p>
			
	<?php 
	}
}