<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 * 
 */

function optionsframework_option_name() {

	$optionsframework_settings = get_option('optionsframework');
	
	// Edit 'options-theme-customizer' and set your own theme name instead
	$optionsframework_settings['id'] = 'live';
	update_option('optionsframework', $optionsframework_settings);
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the "id" fields, make sure to use all lowercase and no spaces.
 *  
 */

function optionsframework_options() {
	
	// Graphic logo or dynamic text
	$logo_type = array(
		"text" => __( 'Text', 'organizedthemes' ),
		"image" => __( 'Image', 'organizedthemes' ),
	);
	
	// True or False
	$tf = array(
		"true" => __( 'Yes', 'organizedthemes' ),
		"false" => __( 'No', 'organizedthemes' ),
	);	
	
	// Yes or No
	$yes = array(
		"true" => __( 'Yes', 'organizedthemes' ),
		"false" => __( 'No', 'organizedthemes' ),
	);
	
	// Yes or No
	$yesno = array(
		"yes" => __( 'Yes', 'organizedthemes' ),
		"no" => __( 'No', 'organizedthemes' ),
	);
	
	// Transition Type
	$transition = array(
		"fade" => __( 'Fade', 'organizedthemes' ),
		"slide" => __( 'Slide', 'organizedthemes' )
	);
	
	// Arrow Color
	$arrow_color = array(
		"white" => __( 'White', 'organizedthemes' ),
		"black" => __( 'Black', 'organizedthemes' )
	);
	
	// Action Bar Options
	$action_options = array(
		"" => __( 'None', 'organizedthemes' ),
		"call" => __( 'Call to Action', 'organizedthemes' ),
		"donation" => __( 'Donation Bar', 'organizedthemes' )
	);
	
	// Choose PayPal or Link
	$paypal_option = array(
		"paypal" => __( 'PayPal', 'organizedthemes' ),
		"custom" => __( 'Custom Link', 'organizedthemes' )
	);

	// content or excerpt
	$content_type = array(
		"excerpt" => __( 'Excerpt', 'organizedthemes' ),
		"content" => __( 'Full Content', 'organizedthemes' )
		);
	
	// Transition Type
	$transition = array("fade" => "Fade","slide" => "Slide");
	
	// Background Options
		$background_repeat = array(
			"repeat" => __( 'Repeat All', 'organizedthemes' ),
			"repeat-y" => __( 'Repeat Vertically', 'organizedthemes' ),
			"repeat-x" => __( 'Repeat Horizontally', 'organizedthemes' ),
			"no-repeat" => __( 'No Repeat', 'organizedthemes' )
			);
		
		$background_attachment = array(
			"scroll" => __( 'Scroll', 'organizedthemes' ),
			"fixed" => __( 'Fixed', 'organizedthemes' )
			);
		
		$background_position_x = array(
			"left" => __( 'Left', 'organizedthemes' ),
			"center" => __( 'Center', 'organizedthemes' ),
			"right" => __( 'Right', 'organizedthemes' )
			);
		
		$background_position_y = array(
			"top" => __( 'Top', 'organizedthemes' ),
			"center" => __( 'Center', 'organizedthemes' ),
			"bottom" => __( 'Bottom', 'organizedthemes' )
			);
	
	// lightbox styling
		$light_style = array(
			"default" => __( 'Default', 'organizedthemes' ),
			"carbono" => __( 'Carbono', 'organizedthemes' ),
			"classic" => __( 'Classic', 'organizedthemes' ),
			"classic_dark" => __( 'Classic Dark', 'organizedthemes' ),
			"evolution" => __( 'Evolution', 'organizedthemes' ),
			"evolution_dark" => __( 'Evolution Dark', 'organizedthemes' ),
			"facebook" => __( 'Facebook', 'organizedthemes' ),
			"minimal" => __( 'Minimalist', 'organizedthemes' ),
			"minimal_dark" => __( 'Minimalist Dark', 'organizedthemes' ),
			"white" => __( 'White and Green', 'organizedthemes' )
		);
	
	
	// Pull all the categories into an array
	$options_categories = array();  
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
    	$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Pull all the pages into an array
	$options_pages = array();  
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
    	$options_pages[$page->ID] = $page->post_title;
	}
		
	// If using image radio buttons, define a directory path
	$imagepath =  get_stylesheet_directory_uri() . '/images/';
		
	$options = array();
		
	$options[] = array( "name" => __( 'General Options', 'organizedthemes' ),
						"type" => "heading");
						
	$options['header_blog_title'] = array( "name" => __( 'Text or Graphic Logo', 'organizedthemes' ),
						"desc" => __( 'Choose between a graphic logo or the site title.', 'organizedthemes' ),
						"id" => "header_blog_title",
						"std" => "Text",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $logo_type);
	
	$options['logo'] = array( "name" => __( 'Logo', 'organizedthemes' ),
						"desc" => __( 'Upload a graphic logo here.', 'organizedthemes' ),
						"id" => "logo",
						"type" => "upload");
	
	$options[] = array( "name" => __( 'Favicon', 'organizedthemes' ),
						"desc" => __( 'Upload a favicon (small icon that sits beside your websites address in a browser navigation bar here.', 'organizedthemes' ),
						"id" => "favicon",
						"std" => "",
						"type" => "upload");
						
	$options[] = array( "name" => __( 'Apple Shortcut Icon', 'organizedthemes' ),
						"desc" => __( 'Upload an icon for an iOS shortcut icon here.  Should be 114 pixels square.', 'organizedthemes' ),
						"id" => "apple",
						"std" => "",
						"type" => "upload");
	
	$options[] = array( "name" => __( 'Include Lightbox Gallery', 'organizedthemes' ),
						"desc" => __( 'If you would like to disable the fancybox, lightbox gallery, select no here.', 'organizedthemes' ),
						"id" => "gallery",
						"std" => "yes",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $yes);
	
	$options[] = array( "name" => __( 'Lightbox Style', 'organizedthemes' ),
						"desc" => __( 'Choose a style for the pop-up lightbox.', 'organizedthemes' ),
						"id" => "lightbox_style",
						"std" => "classic",
						"type" => "select",
						"class" => "tiny", //mini, tiny, small
						"options" => $light_style);
	
	$options[] = array( "name" => __( 'Excerpt Or Full Content', 'organizedthemes' ),
						"desc" => __( 'You can choose to display your full post content or only an excerpt on archive pages.', 'organizedthemes' ),
						"id" => "content_excerpt",
						"std" => "yes",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $content_type);
	
	$options['footer_text'] = array( "name" => __( 'Footer Text','organizedthemes'),
						"desc" => __( 'Text for the left of your footer','organizedthemes'),
						"id" => "footer_text",
						"std" => get_bloginfo('name'),
						"type" => "text");
	
	$options[] = array( 'name' => __( 'Disable Theme Updates', 'organizedthemes' ),
		'desc' => __( 'Disables the theme updater feature.', 'organizedthemes' ),
		'id' => 'disable_theme_updater',
		'std' => false,
		'type' => 'checkbox' );
	
// Home Page Options		
	$options[] = array( "name" => __( 'Home Page', 'organizedthemes' ),
						"type" => "heading");							
	
	$options['action'] = array( "name" => __( 'Choose a Home Page Action Bar', 'organizedthemes' ),
						"desc" => __( 'You can include a donation bar, call to action bar or leave it out.', 'organizedthemes' ),
						"id" => "action",
						"std" => "action",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $action_options);
	
	$options['action_text'] = array( "name" => __( 'Call To Action Bar Text','organizedthemes'),
						"desc" => __( 'The text for your call to action.','organizedthemes'),
						"id" => "action_text",
						"std" => "Call To Action Button",
						"type" => "text");
	
	$options['action_url'] = array( "name" => __( 'Call To Action Link URL','organizedthemes'),
						"desc" => __( 'The URL you would like the action bar to link to.','organizedthemes'),
						"id" => "action_url",
						"std" => "",
						"type" => "text");

								
	$options['description'] = array( "name" => __( 'Donation Bar Description', 'organizedthemes' ),
						"desc" => __( 'Text that overlays the graph.', 'organizedthemes' ),
						"id" => "description",
						"std" => "",
						"type" => "text");
								
	$options['progress'] = array( "name" => __( 'Percentage Toward Goal', 'organizedthemes' ),
						"desc" => __( 'The percentage raised toward your goal.', 'organizedthemes' ),
						"id" => "progress",
						"std" => "",
						"type" => "text");
							
	$options['goal'] = array( "name" => __( 'Donation Goal', 'organizedthemes' ),
						"desc" => __( 'Your goal.  It can be anything.', 'organizedthemes' ),
						"id" => "goal",
						"std" => "",
						"type" => "text");
								
	$options['donate_button'] = array( "name" => __( 'Donation Button', 'organizedthemes' ),
						"desc" => __( 'Text for your donation button.', 'organizedthemes' ),
						"id" => "donate_button",
						"std" => "Donate",
						"type" => "text");
						
	$options['donation_choice'] = array( "name" => __( 'PayPal Or Link To Page', 'organizedthemes' ),
						"desc" => __( 'Choose to send your visitors to PayPal for a donation or a specific URL', 'organizedthemes' ),
						"id" => "donation_choice",
						"std" => "paypal",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $paypal_option);
								
	$options['donate_url'] = array( "name" => __( 'Donation Link URL', 'organizedthemes' ),
						"desc" => __( 'The URL you would like your donate button to link to.', 'organizedthemes' ),
						"id" => "donate_url",
						"std" => "",
						"type" => "text");
								
	$options['paypal'] = array( "name" => __( 'PayPal Email Address', 'organizedthemes' ),
						"desc" => __( 'The email address you would like donations sent to.', 'organizedthemes' ),
						"id" => "paypal",
						"std" => "",
						"type" => "text");
								
	$options['thank_you'] = array( "name" => __( 'Thank You Page', 'organizedthemes' ),
						"desc" => __( 'The URL of the page you would like to send visitors to after leaving PayPal.', 'organizedthemes' ),
						"id" => "thank_you",
						"std" => "",
						"type" => "text");
	
	
	$options[] = array( "name" => __( 'Slideshow Settings','organizedthemes'),
						"desc" => __( '','organizedthemes'),
						"type" => "info");
	
	$options[] = array( "name" => __( 'Automatically Play Slideshow', 'organizedthemes' ),
						"desc" => __( 'Choose yes to have the slideshow begin sliding once the page loads.  If you are using videos, we recommend setting this to NO.', 'organizedthemes' ),
						"id" => "auto",
						"std" => "true",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $tf);
	
	$options[] = array( "name" => __( 'Previous/Next Arros', 'organizedthemes' ),
						"desc" => __( 'Choose yes to display previous/next arrow buttons.', 'organizedthemes' ),
						"id" => "prev_next",
						"std" => "true",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $tf);
	
	$options['arrow_color'] = array( "name" => __( 'Arrow Color', 'organizedthemes' ),
						"desc" => __( 'Choose between white and black arrows.', 'organizedthemes' ),
						"id" => "arrow_color",
						"std" => "white",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $arrow_color);
	
	$options[] = array( "name" => __( 'Animation Type', 'organizedthemes' ),
						"desc" => __( 'The slideshow can either use a fade or a slide for transitions.', 'organizedthemes' ),
						"id" => "type",
						"std" => "slide",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $transition);
	
	$options[] = array( "name" => __( 'Slide Duration','organizedthemes'),
						"desc" => __( 'The amount of time in milliseconds that each slide will be visible.','organizedthemes'),
						"id" => "duration",
						"std" => "5000",
						"type" => "text");
	
	$options[] = array( "name" => __( 'Animation Duration','organizedthemes'),
						"desc" => __( 'The amount of time in milliseconds that it takes to change a slide','organizedthemes'),
						"id" => "transition",
						"std" => "750",
						"type" => "text");


// Podcast Options						
	$options[] = array( "name" => __( 'Podcast','organizedthemes'),
						"type" => "heading");
	
	$options[] = array( "name" => __( 'Podcast Art','organizedthemes'),
						"desc" => __( 'Upload a 1400 pixel by 1400 pixel PNG or JPEG image for your podcast.','organizedthemes'),
						"id" => "podcast_art",
						"type" => "upload");
								
	$options[] = array( "name" => __( 'Podcast Title','organizedthemes'),
						"desc" => __( 'The name for your podcast feed.','organizedthemes'),
						"id" => "podcast_title",
						"std" => "",
						"type" => "text");
								
	$options[] = array( "name" => __( 'Podcast Sub-Title','organizedthemes'),
						"desc" => __( 'The sub-title for your podcast feed.  iTunes has a 255 character limit here.','organizedthemes'),
						"id" => "podcast_subtitle",
						"std" => "",
						"type" => "text");
								
	$options[] = array( "name" => __( 'Podcast Archive URL','organizedthemes'),
						"desc" => __( 'The URL of your podcast archive.','organizedthemes'),
						"id" => "podcast_url",
						"std" => "",
						"type" => "text");
								
	$options[] = array( "name" => __( 'Podcast Author','organizedthemes'),
						"desc" => __( 'The author of your podcast.','organizedthemes'),
						"id" => "podcast_author",
						"std" => "",
						"type" => "text");
								
	$options[] = array( "name" => __( 'Podcast Summary','organizedthemes'),
						"desc" => __( 'Type the summary of your podcast here.','organizedthemes'),
						"id" => "podcast_summary",
						"std" => "",
						"type" => "textarea");
								
	$options[] = array( "name" => __( 'Podcast Owner','organizedthemes'),
						"desc" => __( 'Type the name of the podcast owner here.','organizedthemes'),
						"id" => "podcast_owner",
						"std" => "",
						"type" => "text");
								
	$options[] = array( "name" => __( 'Podcast Email','organizedthemes'),
						"desc" => __( 'Type the email address of your podcast owner here.','organizedthemes'),
						"id" => "podcast_email",
						"std" => "",
						"type" => "text");
								
	$options[] = array( "name" => __( 'iTunes Category','organizedthemes'),
						"desc" => __( 'Type the category of your podcast here.  You can find a list of them <a href="http://www.apple.com/itunes/podcasts/specs.html#categories" target="_blank">here</a>.','organizedthemes'),
						"id" => "podcast_category",
						"std" => "",
						"type" => "text");
								
	$options[] = array( "name" => __( 'iTunes Sub-Category','organizedthemes'),
						"desc" => __( 'Type the sub-category of your podcast here.','organizedthemes'),
						"id" => "podcast_subcategory",
						"std" => "",
						"type" => "text");




															
// Styling Options						
	$options[] = array( "name" => __( 'Styling', 'organizedthemes' ),
						"type" => "heading");
	
	$options[] = array(
		'name' => __('', 'organizedthemes'),
		'desc' => __('All of these styling options are available in the theme customizer.  For the best experience, make changes <a href="'.home_url().'/wp-admin/customize.php">there.</a>', 'organizedthemes'),
		'type' => 'info');
	
	$options[] = array( 'name' => __('Background', 'organizedthemes'),
			'desc' => __('There are multiple backgrounds that are bundled with the theme.  To access them, unzip the ZIP file you downloaded and open it up.  Inside it there will be a folder called "Backgrounds" that contains the image files.', 'organizedthemes'),
			'type' => 'info');
	
	$options['background_image'] = array( "name" => __( 'Background Image', 'organizedthemes' ),
						"desc" => __( 'Upload a background image here.', 'organizedthemes' ),
						"id" => "background_image",
						"std" => get_template_directory_uri() . '/backgrounds/background.jpg',
						"type" => "upload");
	
	$options['background_repeat'] = array( "name" => __( 'Background Repeat', 'organizedthemes' ),
						"desc" => __( 'Set how your background iamge repeats.', 'organizedthemes' ),
						"id" => "background_repeat",
						"std" => "repeat",
						"type" => "select",
						"options" => $background_repeat);
	
	$options['background_attachment'] = array( "name" => __( 'Background Attachment', 'organizedthemes' ),
						"desc" => __( 'Set how your background iamge is attached.', 'organizedthemes' ),
						"id" => "background_attachment",
						"std" => "scroll",
						"type" => "select",
						"options" => $background_attachment);
	
	$options['background_position_horizontal'] = array( "name" => __( 'Background Position (horizontal)', 'organizedthemes' ),
						"desc" => __( 'Chose where the background image begins horizontally.', 'organizedthemes' ),
						"id" => "background_position_horizontal",
						"std" => "center",
						"type" => "select",
						"options" => $background_position_x);
	
	$options['background_position_vertical'] = array( "name" => __( 'Background Position (vertical)', 'organizedthemes' ),
						"desc" => __( 'Chose where the background image begins vertically.', 'organizedthemes' ),
						"id" => "background_position_vertical",
						"std" => "top",
						"type" => "select",
						"options" => $background_position_y);
	
	$options['background_color'] = array( "name" => __( 'Background Color', 'organizedthemes' ),
						"desc" => __( 'Choose a background color', 'organizedthemes' ),
						"id" => "background_color",
						"std" => "#222222",
						"type" => "color");	
	
	$options['site_title_font'] = array( 'name' => __( 'Site Title', 'organizedthemes' ),
			'desc' => __( 'Choose the type for your text logo.', 'organizedthemes' ),
			'id' => 'site_title_font',
			'std' => array( 'size' => '50px', 'face' => 'Open Sans, sans-serif', 'color' => '#ffffff'),
			'type' => 'typography',
			'options' => array(
				'faces' => options_typography_get_google_fonts(),
				'styles' => false,
				'color' => false )
			);
	
					
	$options['logo_color'] = array( "name" => __( 'Text Logo Color', 'organizedthemes' ),
						"desc" => __( 'The color of a text based logo.', 'organizedthemes' ),
						"id" => "logo_color",
						"std" => "",
						"type" => "color");
	
	$options['logo_color_hover'] = array( "name" => __( 'Text Logo Hover Color', 'organizedthemes' ),
						"desc" => __( 'The color of a text based logo while hovering.', 'organizedthemes' ),
						"id" => "logo_color_hover",
						"std" => "",
						"type" => "color");
	
	$options['header_background'] = array( "name" => __( 'Header Background', 'organizedthemes' ),
						"desc" => __( 'Choose a color for your header background', 'organizedthemes' ),
						"id" => "header_background",
						"std" => "",
						"type" => "color");
	
	$options['navigation_type'] = array( 'name' => __( 'Navigation Items', 'organizedthemes' ),
			'desc' => __( 'Sets the type for your navigation menu.', 'organizedthemes' ),
			'id' => 'navigation_type',
			'std' => array( 'size' => '20px', 'face' => 'Open Sans, sans-serif', 'color' => '#ffffff'),
			'type' => 'typography',
			'options' => array(
				'faces' => options_typography_get_google_fonts(),
				'styles' => false,
				'color' => false )
			);
	
	$options['nav_color'] = array( "name" => __( 'Navigation Text Color', 'organizedthemes' ),
						"desc" => __( 'Choose a color for your navigation links', 'organizedthemes' ),
						"id" => "nav_color",
						"std" => "",
						"type" => "color");
	
	$options['nav_color_hover'] = array( "name" => __( 'Navigation Text Color Hover', 'organizedthemes' ),
						"desc" => __( 'Choose a color for your navigation links while hovering', 'organizedthemes' ),
						"id" => "nav_color_hover",
						"std" => "",
						"type" => "color");
	
	$options['nav_drop'] = array( "name" => __( 'Drop-Down Background', 'organizedthemes' ),
						"desc" => __( 'The background color for drop-down menus', 'organizedthemes' ),
						"id" => "nav_drop",
						"std" => "",
						"type" => "color");
	
	$options['action_background'] = array( "name" => __( 'Action Bar Background', 'organizedthemes' ),
						"desc" => __( 'The background color of the call to action bar on the home page', 'organizedthemes' ),
						"id" => "action_background",
						"std" => "",
						"type" => "color");
	
	$options['action_text_color'] = array( "name" => __( 'Action Bar Text Color', 'organizedthemes' ),
						"desc" => __( 'The text color of the call to action bar', 'organizedthemes' ),
						"id" => "action_text_color",
						"std" => "",
						"type" => "color");
	
	$options['action_text_hover'] = array( "name" => __( 'Action Bar Text Color Hover', 'organizedthemes' ),
						"desc" => __( 'The text color of the call to action bar while hovering', 'organizedthemes' ),
						"id" => "action_text_hover",
						"std" => "",
						"type" => "color");
	
	
	$options['donation_base_color'] = array( "name" => __( 'Donation Graph Base', 'organizedthemes' ),
						"desc" => __( 'Choose the bottom color of the donation graph.', 'organizedthemes' ),
						"id" => "donation_base_color",
						"std" => "",
						"type" => "color");	
	
	$options['donation_progress_color'] = array( "name" => __( 'Donation Graph Progress Color', 'organizedthemes' ),
						"desc" => __( 'Choose the color of the donation graph progress.', 'organizedthemes' ),
						"id" => "donation_progress_color",
						"std" => "",
						"type" => "color");
	
	
	
	
	
	
	$options['link'] = array( "name" => __( 'Link Color', 'organizedthemes' ),
						"desc" => __( 'Sets the default color for links.', 'organizedthemes' ),
						"id" => "link",
						"std" => "",
						"type" => "color");	
	
	$options['link_hover'] = array( "name" => __( 'Link Hover Color', 'organizedthemes' ),
						"desc" => __( 'Sets the hover state color for links.', 'organizedthemes' ),
						"id" => "link_hover",
						"std" => "",
						"type" => "color");
	
	$options['button_color'] = array( "name" => __( 'Button Text', 'organizedthemes' ),
						"desc" => __( 'Sets the text color of buttons.', 'organizedthemes' ),
						"id" => "button_color",
						"std" => "",
						"type" => "color");
	
	$options['button_background'] = array( "name" => __( 'Button Background', 'organizedthemes' ),
						"desc" => __( 'Sets the background color of buttons.', 'organizedthemes' ),
						"id" => "button_background",
						"std" => "",
						"type" => "color");
	
	$options['button_color_hover'] = array( "name" => __( 'Button Text Hover', 'organizedthemes' ),
						"desc" => __( 'Sets the text color of buttons while hovering.', 'organizedthemes' ),
						"id" => "button_color_hover",
						"std" => "",
						"type" => "color");
	
	$options['button_background_hover'] = array( "name" => __( 'Button Background Hover', 'organizedthemes' ),
						"desc" => __( 'Sets the background color of buttons while hovering.', 'organizedthemes' ),
						"id" => "button_background_hover",
						"std" => "",
						"type" => "color");
						
	$options['content_background'] = array( "name" => __( 'Content Background', 'organizedthemes' ),
						"desc" => __( 'Sets the background color of the main content areas.', 'organizedthemes' ),
						"id" => "content_background",
						"std" => "",
						"type" => "color");
	
	$options['body_font'] = array( 'name' => __( 'Content Font', 'organizedthemes' ),
			'desc' => __( 'This is used for the main conent and widgets.', 'organizedthemes' ),
			'id' => 'body_font',
			'std' => array( 'size' => '16px', 'face' => 'Open Sans, sans-serif', 'color' => '#000000'),
			'type' => 'typography',
			'options' => array(
				'faces' => options_typography_get_google_fonts(),
				'styles' => false,
				'color' => false )
			);
	
	$options['content_text'] = array( "name" => __( 'Content Text Color', 'organizedthemes' ),
						"desc" => __( 'Sets the text color of the main content areas.', 'organizedthemes' ),
						"id" => "content_text",
						"std" => "",
						"type" => "color");
	
	$options['heading_font'] = array( 'name' => __( 'Headings', 'organizedthemes' ),
			'desc' => __( 'Choose a font for your page titles and other headings (h1, h2, h3, h4, h5, h6)', 'organizedthemes' ),
			'id' => 'heading_font',
			'std' => array( 'size' => '24px', 'face' => 'Open Sans, sans-serif', 'color' => '#000000'),
			'type' => 'typography',
			'options' => array(
				'faces' => options_typography_get_google_fonts(),
				'styles' => false,
				'sizes' => false,
				'color' => false )
			);
	
	$options['headings'] = array( "name" => __( 'Content Headings Color', 'organizedthemes' ),
						"desc" => __( 'Sets the text color of the headings and titles.', 'organizedthemes' ),
						"id" => "headings",
						"std" => "",
						"type" => "color");
	
	$options['sidebar_background'] = array( "name" => __( 'Sidebar Background', 'organizedthemes' ),
						"desc" => __( 'Sets the background color of the sidebar areas.', 'organizedthemes' ),
						"id" => "sidebar_background",
						"std" => "",
						"type" => "color");
	
	$options['sidebar_text'] = array( "name" => __( 'Sidebar Text', 'organizedthemes' ),
						"desc" => __( 'Sets the text color of the sidebar areas.', 'organizedthemes' ),
						"id" => "sidebar_text",
						"std" => "",
						"type" => "color");
	
	$options['footer_color'] = array( "name" => __( 'Footer Text Color', 'organizedthemes' ),
						"desc" => __( 'The color the text in your footer.', 'organizedthemes' ),
						"id" => "footer_color",
						"std" => "",
						"type" => "color");
	
	$options['home_widget_height'] = array( "name" => __( 'Home Widget Height','organizedthemes'),
						"desc" => __( 'Set the height of your home page widget containers in pixels','organizedthemes'),
						"id" => "home_widget_height",
						"std" => "",
						"type" => "text");
														
	$options[] = array(
		'name' => __('Advanced Style Settings', 'organizedthemes'),
		'desc' => __('', 'organizedthemes'),
		'type' => 'info');
	
	$options[] = array( 'name' => __( 'Disable Fonts', 'organizedthemes' ),
		'desc' => __( 'Turns off the output of Google fonts.', 'organizedthemes' ),
		'id' => 'disable_fonts',
		'std' => false,
		'type' => 'checkbox' );
				
							
	$options[] = array( "name" => __( 'Custom CSS', 'organizedthemes' ),
		"desc" => __( 'Add any custom CSS you would like to use here.', 'organizedthemes' ),
		"id" => "custom_css",
		"std" => "",
		"type" => "textarea"); 
						
	return $options;
}